Function ancillary_space
pub const fn ancillary_space<T>() -> usizewhere
T: AncillaryData,Available on crate features
io and ancillary only.Expand description
Returns the buffer size required to hold one ancillary message carrying a
value of type T.
This is the platform-appropriate equivalent of CMSG_SPACE(T::SIZE) on
Unix or WSA_CMSG_SPACE(T::SIZE) on Windows, and can be used as a const
generic argument for AncillaryBuf.